@@ -64,7 +64,7 @@ except NameError:
     unicode = str
 
 
-__version__ = '0.9.6'
+__version__ = '0.9.7'
 
 
 CR = '\r'
@@ -89,13 +89,13 @@ DEFAULT_IGNORE = 'E24'
 
 # W602 is handled separately due to the need to avoid "with_traceback".
 CODE_TO_2TO3 = {
+    'E721': ['idioms'],
     'W601': ['has_key'],
     'W603': ['ne'],
     'W604': ['repr'],
     'W690': ['apply',
              'except',
              'exitfunc',
-             'idioms',
              'import',
              'numliterals',
              'operator',
@@ -193,6 +193,7 @@ def continued_indentation(logical_line, tokens, indent_level, noqa):
     last_token_multiline = None
     line = None
     last_line = ''
+    last_line_begins_with_multiline = False
     for token_type, text, start, end, line in tokens:
 
         newline = row < start[0] - first_row
@@ -200,17 +201,18 @@ def continued_indentation(logical_line, tokens, indent_level, noqa):
             row = start[0] - first_row
             newline = (not last_token_multiline and
                        token_type not in (tokenize.NL, tokenize.NEWLINE))
+            last_line_begins_with_multiline = last_token_multiline
 
         if newline:
-            # this is the beginning of a continuation line.
+            # This is the beginning of a continuation line.
             last_indent = start
 
-            # record the initial indent.
+            # Record the initial indent.
             rel_indent[row] = pep8.expand_indent(line) - indent_level
 
             if depth:
-                # a bracket expression in a continuation line.
-                # find the line that it was opened on
+                # A bracket expression in a continuation line.
+                # Find the line that it was opened on.
                 for open_row in range(row - 1, -1, -1):
                     if parens[open_row]:
                         break
@@ -303,7 +305,11 @@ def continued_indentation(logical_line, tokens, indent_level, noqa):
         last_token_multiline = (start[0] != end[0])
         last_line = line
 
-    if indent_next and pep8.expand_indent(line) == indent_level + 4:
+    if (
+        indent_next and
+        not last_line_begins_with_multiline and
+        pep8.expand_indent(line) == indent_level + 4
+    ):
         yield (last_indent, 'E125 {0}'.format(indent_level + 8))
 del pep8._checks['logical_line'][pep8.continued_indentation]
 pep8.register_check(continued_indentation)
@@ -364,7 +370,6 @@ class FixPEP8(object):
         self.fix_e122 = self._fix_reindent
         self.fix_e123 = self._fix_reindent
         self.fix_e124 = self._fix_reindent
-        self.fix_e125 = self._fix_reindent
         self.fix_e126 = self._fix_reindent
         self.fix_e127 = self._fix_reindent
         self.fix_e128 = self._fix_reindent
@@ -543,18 +548,29 @@ class FixPEP8(object):
         This is done by adding or removing from its initial indent only.
 
         """
-        num_indent = int(result['info'].split()[1])
+        num_indent_spaces = int(result['info'].split()[1])
         line_index = result['line'] - 1
         target = self.source[line_index]
 
-        # When multiline strings are involved, pep8 reports the error as
-        # being at the start of the multiline string, which doesn't work
-        # for us.
-        if ('"""' in target or "'''" in target):
-            return []
+        self.source[line_index] = ' ' * num_indent_spaces + target.lstrip()
 
-        self.source[line_index] = (
-            ' ' * num_indent + target.lstrip())
+    def fix_e125(self, result):
+        """Fix indentation undistinguish from the next logical line."""
+        num_indent_spaces = int(result['info'].split()[1])
+        line_index = result['line'] - 1
+        target = self.source[line_index]
+
+        spaces_to_add = num_indent_spaces - len(_get_indentation(target))
+        indent = len(_get_indentation(target))
+        modified_lines = []
+
+        while len(_get_indentation(self.source[line_index])) >= indent:
+            self.source[line_index] = (' ' * spaces_to_add +
+                                       self.source[line_index])
+            modified_lines.append(1 + line_index)  # Line indexed at 1.
+            line_index -= 1
+
+        return modified_lines
 
     def fix_e201(self, result):
         """Remove extraneous whitespace."""
@@ -562,14 +578,7 @@ class FixPEP8(object):
         target = self.source[line_index]
         offset = result['column'] - 1
 
-        # When multiline strings are involved, pep8 reports the error as
-        # being at the start of the multiline string, which doesn't work
-        # for us.
-        if (
-            '"""' in target or
-            "'''" in target or
-            target.rstrip().endswith('\\')
-        ):
+        if is_probably_part_of_multiline(target):
             return []
 
         fixed = fix_whitespace(target,
@@ -666,12 +675,7 @@ class FixPEP8(object):
         target = self.source[line_index]
         offset = result['column'] - 1
 
-        # When multiline strings are involved, pep8 reports the error as
-        # being at the start of the multiline string, which doesn't work
-        # for us.
-        if ('"""' in target or
-            "'''" in target or
-                target.rstrip().endswith('\\')):
+        if is_probably_part_of_multiline(target):
             return []
 
         fixed = fix_whitespace(target,
@@ -950,7 +954,7 @@ class FixPEP8(object):
         return range(1, 1 + original_length)
 
 
-def fix_e26(source, aggressive=False, select='', ignore=''):
+def fix_e269(source, aggressive=False):
     """Format block comments."""
     if '#' not in source:
         # Optimization.
@@ -972,8 +976,12 @@ def fix_e26(source, aggressive=False, select='', ignore=''):
 
             # Normalize beginning if not a shebang.
             if len(line) > 1:
-                # Leave multiple spaces like '#    ' alone.
-                if line.count('#') > 1 or line[1].isalnum():
+                if (
+                    # Leave multiple spaces like '#    ' alone.
+                    (line.count('#') > 1 or line[1].isalnum())
+                    # Leave stylistic outlined blocks alone.
+                    and not line.rstrip().endswith('#')
+                ):
                     line = '# ' + line.lstrip('# \t')
 
             fixed_lines.append(indentation + line)
@@ -1014,17 +1022,20 @@ def code_to_2to3(select, ignore):
     return fixes
 
 
-def fix_w6(source, aggressive=True, select='', ignore=''):
+def fix_2to3(source, aggressive=True, select=None, ignore=None):
     """Fix various deprecated code (via lib2to3)."""
     if not aggressive:
         return source
 
+    select = select or []
+    ignore = ignore or []
+
     return refactor(source,
                     code_to_2to3(select=select,
                                  ignore=ignore))
 
 
-def fix_w602(source, aggressive=True, select='', ignore=''):
+def fix_w602(source, aggressive=True):
     """Fix deprecated form of raising exception."""
     if not aggressive:
         return source
@@ -1767,11 +1778,13 @@ def mutual_startswith(a, b):
 
 def code_match(code, select, ignore):
     if ignore:
+        assert not isinstance(ignore, str)
         for ignored_code in [c.strip() for c in ignore]:
             if mutual_startswith(code.lower(), ignored_code.lower()):
                 return False
 
     if select:
+        assert not isinstance(select, str)
         for selected_code in [c.strip() for c in select]:
             if mutual_startswith(code.lower(), selected_code.lower()):
                 return True
@@ -1794,8 +1807,7 @@ def fix_code(source, options=None):
 
 def fix_string(source, options=None):
     """Deprecated."""
-    warnings.warn('fix_string() is deprecated; use fix_code() instead',
-                  DeprecationWarning)
+    warnings.warn('fix_string() is deprecated; use fix_code() instead')
     return fix_code(source, options)
 
 
@@ -1899,9 +1911,12 @@ def apply_global_fixes(source, options):
                 print('--->  Applying global fix for {0}'.format(code.upper()),
                       file=sys.stderr)
             source = function(source,
-                              aggressive=options.aggressive,
-                              select=options.select,
-                              ignore=options.ignore)
+                              aggressive=options.aggressive)
+
+    source = fix_2to3(source,
+                      aggressive=options.aggressive,
+                      select=options.select,
+                      ignore=options.ignore)
 
     return source
 
@@ -2073,6 +2088,10 @@ def supported_fixes():
         yield (code.upper() + (4 - len(code)) * ' ',
                re.sub(r'\s+', ' ', docstring_summary(function.__doc__)))
 
+    for code in sorted(CODE_TO_2TO3):
+        yield (code.upper() + (4 - len(code)) * ' ',
+               re.sub(r'\s+', ' ', docstring_summary(fix_2to3.__doc__)))
+
 
 def docstring_summary(docstring):
     """Return summary of docstring."""
@@ -2296,6 +2315,21 @@ def is_python_file(filename):
     return True
 
 
+def is_probably_part_of_multiline(line):
+    """Return True if line is likely part of a multiline string.
+
+    When multiline strings are involved, pep8 reports the error as
+    being at the start of the multiline string, which doesn't work for
+    us.
+
+    """
+    return (
+        '"""' in line or
+        "'''" in line or
+        line.rstrip().endswith('\\')
+    )
+
+
 def main():
     """Tool main."""
     try:
